<?php


class fotoliaApiClient
{
    // api_key, $url, $path : mandatory vars for each request, set in config.php
    var $api_key;
    var $url;
    var $path;

    // used in getSearchResults method for parameters that are not in $_REQUEST
    // => parameters set in the page like getSearchResults with serie_id set.
    var $forced_params;

    function fotoliaApiClient($api_key, $url, $path)
    {

        $this->api_key  = $api_key;
        $this->url      = $url;
        $this->path     = $path;

        $this->search_params = array(
            'keywords',
            'words',
            'language_id',
            'color_name',
            'creator_id',
            'k',
            'serie_id',
            'model_id',
            'similar_id',
            'cat1_id',
            'cat2_id',
			'gallery_id',
            'category_ids',
            'isolated',
            'lightbox_id32',
            'filters',
            'country_id',
            'forward_to',
            'content_ids',
            'offset',
            'order',
            'thumbnail_size',
            'limit',
            'similia_id',
            'media_id',
            'detail_level',
			'action',
        );

        $this->type_of_stats = array(
            'member_viewed_photos',
            'member_downloaded_photos',
            'member_bought_photos',
            'member_earned_credits',
        );

        $this->displayed_period = array(
            'day',
            'week',
            'month',
            'quarter',
            'year',
        );

        $this->easy_date_periods = array(
            'all',
            'today',
            'yesterday',
            'one_day',
            'two_days',
            'three_days',
            'one_week',
            'one_month',
        );

    }


    /*
     * Prepare the xml rpc request and send to the servers
     *
     * @param string $method the method name
     * @param array $params the parameters to send in the xmlrpc request
     * @param optional string $session_id valid php session id returned by xmlrpc.loginUser method
     * @return $result
     *
     */
    function request($method, $params, $session_id='')
    {
        //if ( is_array($params) && count($params)>0 ) {

            $xmlrpc_params = array();

            // always send the api key as first parameter
            $xmlrpc_params[] = XMLRPC_prepare($this->api_key);

            if ($method == "xmlrpc.getSearchResults") {

                $xmlrpc_params[] = XMLRPC_prepare( $this->prepareSearch($params) );

            } else {

                if ( is_array($params) && count($params) ) {
                    foreach ( $params as $name => $value ){
                        if ($method != 'xmlrpc.loginUser' && $method != 'user.loginUser') {
                            // prepare each parameter for the xml rpc request
                            $int_value = intval($value);
                            if ($value == strval($int_value)) {
                                $value = $int_value;
                            } else {
                                $float_value = floatval($value);
                                if ($value == strval($float_value)) {
                                    $value = $float_value;
                                }
                            }
                        }
                        $xmlrpc_params[] = XMLRPC_prepare($value);
                    }
                }
            }

            // send request to the server
            $result = XMLRPC_request ( $this->url, $this->path, array($method),  $xmlrpc_params, $user_agent='', $session_id);

            $result = $result[1];

            return $result;

        //}

    }


    /*
     *
     * Automatically prepare the search parameters for the xmlrpc request
     * Retrieves all possible search parameters from $this->search_params set in constructor
     *
     * @return $xmlrpc_params
     *
     */
    function prepareSearch($params) {

		$xmlrpc_params = array();

        foreach ($this->search_params as $value) {

            if ( isset($params[$value]) && $params[$value]<>'' ) {

                if ( is_array($params[$value]) ) {
                    foreach ($params[$value] as $filterName => $filterValue) {
                        $xmlrpc_params[$value][$filterName] = $filterValue;
                    }
                } else {
                    $xmlrpc_params[$value] = $params[$value];
                }

            } elseif ( isset($this->forced_params[$value]) ) {
                $xmlrpc_params[$value] = $this->forced_params[$value];
            }

        }

        /*if ( !isset($_REQUEST['offset']) ) {
            $xmlrpc_params['offset'] = (int)0;
        }*/

        return $xmlrpc_params;

    }


    /*
     *
     * Automatically prepare the query string for the search pagination
     * Retrieves all possible search parameters from $this->search_params set in constructor
     *
     * @return $query_string
     *
     */
    function buildSearchQueryString ()
    {
        $query_string = '';

        foreach ($this->search_params as $value) {

            if ( isset($_REQUEST[$value]) && $_REQUEST[$value]<>'' ) {

                if ( is_array($_REQUEST[$value]) ) {

                    foreach ($_REQUEST[$value] as $filterName => $filterValue) {

                        $query_string .= '&filters[' . htmlentities($filterName) . ']=' . htmlentities($filterValue);

                    }

                } else {
					//As "offset" will change in the URL of pagination buttons, every other value is stored to be added later in the URL
					if ($value <> "offset") {
						$query_string .= '&' . htmlentities($value) . '=' . $_REQUEST[$value];
	                    $xmlrpc_params[$value] = $_REQUEST[$value];
					}

                }

            } elseif ( isset($this->forced_params[$value]) ) {

                $query_string .= '&' . htmlentities($filterName) . '=' . htmlentities($filterValue);

            }

        }

        return $query_string;

    }


    /*
     *
     * Automatically prepare the page number and links for navigation through results
     *
     * @return $pagination
     *
     */
    function getSearchPagination($result)
    {   if (isset($result['nb_results'])) {
            if (! $result['nb_results']) return '';
        }
        
		$pagination = '';
		$previous_link_qs = '';
		$next_link_qs = '';
		//If no offset is set in the $_REQUEST array then it takes the value of 0
		if (!isset($_REQUEST['offset'])) {
			$offset = 0;
		} else {
			$offset = $_REQUEST['offset'];
		}

		if (isset($result['navigation_links'])) {
	        $current_page_number    = $result['navigation_links']['currentPageNumber'];
			$previous_link_qs       = str_replace('/Xmlrpc/rpc?', '', $result['navigation_links']['previous']); // query string
			$next_link_qs           = str_replace('/Xmlrpc/rpc?', '', $result['navigation_links']['next']); // query string
		}
		//The values in $_REQUEST are stored in this variable to be used later in links.
        $query_string = $this->buildSearchQueryString();

		//The "Previous" button
		if ($previous_link_qs != NULL) {
			//$pagination .= '<a href="' . $GLOBALS['search_script_url'] . '?' . $previous_link_qs . $query_string .'" class="href_pagi"><div class="pagination">&#171; Previous</div></a>';
                        $pagination .= '<a  href="#"  onclick="javascript:fotolia_ajax_search(&quot;'. $previous_link_qs . '&quot;);" class="href_pagi"><div class="pagination">&#171; Previous</div></a>';

		}

		//Each page is then added to the list
        foreach ($result['navigation_links']['pagination'] as $page_number => $page_qs ) {
			if ($page_qs==''){
                $pagination .= '<div class="pagination"> ... </div>';
            } else {
                $current_qs = str_replace('/Xmlrpc/rpc?', '', $page_qs);//. $query_string;
                //$current_qs = '&action=' . $_REQUEST['action'] . $query_string;
                //$pagination .= '<a href="' . $GLOBALS['search_script_url'] . '?' . $current_qs .'" class="href_pagi"><div class="';
                $pagination .= '<a href="#"  onclick="javascript:fotolia_ajax_search(&quot;'. $current_qs . '&quot;);" class="href_pagi"><div class="';

				//The offset number is detected to be able to change the button style of the current page
				$current_url = explode ("&", $current_qs);
				$current_offset = NULL;
				foreach ($current_url as $key => $value) {
					$esplode_url = explode ("=", $current_url[$key]);
					foreach ($esplode_url as $key2 => $value2) {
						if ($esplode_url[$key2] == "offset") {
							$current_offset = $esplode_url[$key2+1];
						}
					}
				}

				if ($offset == $current_offset) {
					$pagination .= "pagination_current";
				} else {
					$pagination .= "pagination";
				}

				$pagination .= '">' .$page_number . '</div></a>';
            }
        }

		//The "Next" button
		if ($next_link_qs != NULL) {
			//$pagination .= '<a href="' . $GLOBALS['search_script_url'] . '?' . $next_link_qs . $query_string .'" class="href_pagi"><div class="pagination">Next &#187;</div></a>';
                         $pagination .= '<a href="#"  onclick="javascript:fotolia_ajax_search(&quot;'. $next_link_qs . '&quot;);" class="href_pagi"><div class="pagination">Next &#187;</div></a>';

		}

        return $pagination;

    }

    /*public function prepareStatistics()
    {

    }*/

}
?>